/***********************************************************************/
/* Open Visualization Data Explorer                                    */
/* (C) Copyright IBM Corp. 1989,1999                                   */
/* ALL RIGHTS RESERVED                                                 */
/* This code licensed under the                                        */
/*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
/***********************************************************************/
/*
 * $Header: /src/master/dx/src/exec/dxmods/echo.h,v 1.2 2006/06/10 16:33:58 davidt Exp $
 */

#include <dxconfig.h>


#ifndef  _ECHO_H_
#define  _ECHO_H_

#include <dx/dx.h>

Error _dxf_ConvertObjectsToStringValues(Object *, int, char **, int);

#endif /* _ECHO_H_ */

